@@ -1,6 +1,7 @@
 /*
     SPDX-FileCopyrightText: 2008 Nicola Gigante <nicola.gigante@gmail.com>
     SPDX-FileCopyrightText: 2009-2010 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -11,9 +12,9 @@
 #include <QObject>
 #include <QMap>
 #include <QDBusMessage>
-#include <QDBusConnection>
 #include <QTimer>
 #include <QMetaMethod>
+#include <QDBusConnectionInterface>
 
 #include "BackendsManager.h"
 #include "kf5authadaptor.h"
@@ -349,4 +350,13 @@ void debugMessageReceived(int t, const QString &message)
     }
 }
 
+int DBusHelperProxy::callerUid() const
+{
+    QDBusConnectionInterface *iface = connection().interface();
+    if (!iface) {
+        return -1;
+    }
+    return iface->serviceUid(message().service());
+}
+
 } // namespace Auth
