@@ -1,20 +1,8 @@
 /*
-*   Copyright (C) 2010 Dario Freddi <drf@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Lesser General Public License as published by
-*   the Free Software Foundation; either version 2.1 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU Lesser General Public License
-*   along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
+    SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef FAKEHELPERPROXY_H
@@ -42,6 +30,7 @@ public:
     bool initHelper(const QString &name) override;
     void stopAction(const QString &action, const QString &helperID) override;
     void executeAction(const QString &action, const QString &helperID, const DetailsMap &details, const QVariantMap &arguments, int timeout = -1) override;
+    int callerUid() const override;
 };
 
 }
