@@ -1,21 +1,9 @@
 /*
-*   Copyright (C) 2008 Nicola Gigante <nicola.gigante@gmail.com>
-*   Copyright (C) 2009 Dario Freddi <drf@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Lesser General Public License as published by
-*   the Free Software Foundation; either version 2.1 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU Lesser General Public License
-*   along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
+    SPDX-FileCopyrightText: 2008 Nicola Gigante <nicola.gigante@gmail.com>
+    SPDX-FileCopyrightText: 2009 Dario Freddi <drf@kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kauthhelpersupport.h"
@@ -43,6 +31,9 @@ static inline void closelog() {}
 
 #include <QCoreApplication>
 #include <QTimer>
+#ifdef Q_OS_UNIX
+#include <QTextCodec>
+#endif
 
 #include "BackendsManager.h"
 
@@ -63,9 +54,9 @@ static void fixEnvironment()
     const char *home = "HOME";
     if (getenv(home) == nullptr) {
         struct passwd *pw = getpwuid(getuid());
-        int overwrite = 0;
 
         if (pw != nullptr) {
+            int overwrite = 0;
             setenv(home, pw->pw_dir, overwrite);
         }
     }
@@ -76,9 +67,20 @@ int HelperSupport::helperMain(int argc, char **argv, const char *id, QObject *re
 {
 #ifdef Q_OS_UNIX
     fixEnvironment();
+    //As we don't inherit lang, the locale could be something that doesn't support UTF-8. Force it
+    auto utf8Codec = QTextCodec::codecForName("UTF-8");
+    if (utf8Codec) {
+        QTextCodec::setCodecForLocale(utf8Codec);
+    }
 #endif
 
+#ifdef Q_OS_OSX
+    openlog(id, LOG_CONS|LOG_PID, LOG_USER);
+    int logLevel = LOG_WARNING;
+#else
     openlog(id, 0, LOG_USER);
+    int logLevel = LOG_DEBUG;
+#endif
     qInstallMessageHandler(&HelperSupport::helperDebugHandler);
 
     // NOTE: The helper proxy might use dbus, and we should have the qapp
@@ -86,7 +88,7 @@ int HelperSupport::helperMain(int argc, char **argv, const char *id, QObject *re
     QCoreApplication app(argc, argv);
 
     if (!BackendsManager::helperProxy()->initHelper(QString::fromLatin1(id))) {
-        syslog(LOG_DEBUG, "Helper initialization failed");
+        syslog(logLevel, "Helper initialization failed");
         return -1;
     }
 
@@ -153,4 +155,9 @@ bool HelperSupport::isStopped()
     return BackendsManager::helperProxy()->hasToStopAction();
 }
 
+int HelperSupport::callerUid()
+{
+    return BackendsManager::helperProxy()->callerUid();
+}
+
 } // namespace Auth
